#
# spec file for package upower
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# Do not build against libimobile and libplist by default
# Reading out battery and charging state of USB connected iPod/iPad
# does not justify the introduction of these dependencies
%bcond_with libimobile
%if %{with libimobile}
%define idevice enabled
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
%define libplist2 1
%else
%define libplist2 0
%endif
%else
%define idevice disabled
%endif
Name:           upower
Version:        1.90.7.13+git.4f1ef04
Release:        2.1
Summary:        Power Device Enumeration Framework
License:        GPL-2.0-or-later
Group:          System/Daemons
URL:            https://upower.freedesktop.org/
#Source:         https://gitlab.freedesktop.org/upower/upower/-/archive/v%%{version}/upower-v%%{version}.tar.bz2
Source:         %{name}-%{version}.tar.zst
# PATCH-FIX-OPENSUSE: Skip installation of test-only dependencies
Patch1:         skip-tests-install.patch
BuildRequires:  gobject-introspection-devel >= 0.9.9
BuildRequires:  gtk-doc >= 1.11
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  meson >= 0.60.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.66.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gudev-1.0) >= 235
BuildRequires:  pkgconfig(libusb-1.0) >= 1.0.0
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
%{?systemd_requires}
%if %{with libimobile}
BuildRequires:  pkgconfig(libimobiledevice-1.0) >= 0.9.7
%if %libplist2
BuildRequires:  pkgconfig(libplist-2.0)
%else
BuildRequires:  pkgconfig(libplist) >= 0.12
%endif
%endif

%description
UPower is an abstraction for enumerating power devices, listening to
device events and querying history and statistics. Any application or
service on the system can access the org.freedesktop.UPower service
via the system message bus. Some operations (such as suspending the
system) are restricted using PolicyKit.

%package -n libupower-glib3
Summary:        Power Device Enumeration Framework - Library
Group:          System/Daemons
Recommends:     %{name}

%description -n libupower-glib3
UPower is an abstraction for enumerating power devices, listening to
device events and querying history and statistics. Any application or
service on the system can access the org.freedesktop.UPower service
via the system message bus. Some operations (such as suspending the
system) are restricted using PolicyKit.

%package -n typelib-1_0-UpowerGlib-1_0
Summary:        Power Device Enumeration Framework - Introspection bindings
Group:          System/Daemons

%description -n typelib-1_0-UpowerGlib-1_0
UPower is an abstraction for enumerating power devices, listening to
device events and querying history and statistics. Any application or
service on the system can access the org.freedesktop.UPower service
via the system message bus. Some operations (such as suspending the
system) are restricted using PolicyKit.

This package provides the GObject Introspection bindings for
libupower-glib.

%package -n libupower-glib-devel
Summary:        Power Device Enumeration Framework - Development Files
Group:          Development/Libraries/Other
Requires:       libupower-glib3 = %{version}
Requires:       typelib-1_0-UpowerGlib-1_0 = %{version}
Provides:       %{name}-devel = %{version}

%description -n libupower-glib-devel
UPower is an abstraction for enumerating power devices, listening to
device events and querying history and statistics. Any application or
service on the system can access the org.freedesktop.UPower service
via the system message bus. Some operations (such as suspending the
system) are restricted using PolicyKit.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	--libexecdir=%{_libexecdir}/upower \
	-Didevice=%{idevice} \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}

%pre
%service_add_pre upower.service

%post
%{?udev_rules_update:%udev_rules_update}
%service_add_post upower.service
%udev_hwdb_update

%preun
%service_del_preun upower.service

%postun
%service_del_postun upower.service
%udev_hwdb_update

%ldconfig_scriptlets -n libupower-glib3

%files
%license COPYING
%doc AUTHORS NEWS README.md
%dir %{_sysconfdir}/UPower
%config(noreplace) %{_sysconfdir}/UPower/UPower.conf
%{_bindir}/upower
%dir %{_libexecdir}/upower
%{_libexecdir}/upower/upowerd
%{_udevrulesdir}/*.rules
%{_udevhwdbdir}/*.hwdb
%{_unitdir}/upower.service
%{_datadir}/dbus-1/system.d/org.freedesktop.UPower.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.UPower.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.UPower.Device.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.UPower.KbdBacklight.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.UPower.service
%{_mandir}/man1/upower.1%{?ext_man}
%{_mandir}/man7/UPower.7%{?ext_man}
%{_mandir}/man8/upowerd.8%{?ext_man}
%dir %{_localstatedir}/lib/upower
%{_datadir}/polkit-1/actions/org.freedesktop.upower.policy
%{_datadir}/zsh/site-functions/_upower

%files -n libupower-glib3
%{_libdir}/libupower-glib.so.*

%files -n typelib-1_0-UpowerGlib-1_0
%{_libdir}/girepository-1.0/UPowerGlib-1.0.typelib

%files -n libupower-glib-devel
%doc %{_datadir}/gtk-doc/
%{_includedir}/libupower-glib/
%{_libdir}/pkgconfig/upower-glib.pc
%{_libdir}/libupower-glib.so
%{_datadir}/gir-1.0/UPowerGlib-1.0.gir

%files lang -f %{name}.lang

%changelog
* Mon Mar 24 2025 Thomas Renninger <trenn@suse.de>
- Make dependency on libimobile and libplist optional and disbled
  by default:
  Reading out battery and charging state of USB connected iPod/iPad
  does not justify the introduction of these dependencies for this core
  package.
* Thu Feb 13 2025 trenn@suse.de
- Upower is a mature tool with mostly fixes being added, let's
  move over to a "take the very latest git HEAD code base by default
  approach". Also show the amount of additional patches on top of latest
  public version and the latest git patch hash the sources are based
  on in the version format (see below)
- Update to version 1.90.7.13+git.4f1ef04:
  * linux: integration-test: a test case for Dualshock4 with a headphone jack
  * linux: up-device-supply: Update the model name after changing the device type
  * linux: device_supply: Prioritize Gaming Input
  * dbus: UPower.xml: Update GetCriticalAction Values
  * linux: integration-test: test case for the removable battery
  * src: up-device-battery: Reset values when the battery is not present
  * src: up-daemon: skip the battery if present = 0
  * Update LINGUAS
  * pre-commit-config: Remove deprecated default_stages "commit"
  * contrib: setup: Install and setup pre-commit
- Remove upstreamed patch
  D faa6d8a6b3dd92ab61cd3c5515dfd120ccb7e74b.patch
* Fri Jan  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Add faa6d8a6b3dd92ab61cd3c5515dfd120ccb7e74b.patch -- dbus: show
  charge-threshold-* status as yes/no.
* Tue Nov  5 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.90.6:
  * Fractional battery percentage.
  * CI enhancement.
  * Tweak the default battery charging threshold to 75-80.
  * Fix g_object_weak_ref: assertion 'g_atomic_int_get
    (&object->ref_count) >= 1' failed.
- Changes from version 1.90.5:
  * Suspend and Ignore as the CriticalPowerActions.
  * Support for battery charging threshold.
  * Tweak the device priority to make sure the device kind joystick
    can be correctly shown.
- Add pkgconfig(polkit-gobject-1) BuildRequires: New dependency.
* Tue Oct 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop rcFOO symlinks (PED-266).
* Sat Jul  6 2024 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update to version 1.90.4:
  * Resolved high disk and CPU rate.
  * Stop guessing the unknown battery as a power supply.
  * Continue to support lid handling.
  * Fix org.freedesktop.UPower: EnergyRate is a positive value.
  * Fix uni-test python script.
- Switch to tagged release.
- Update BuildRequires minimum versions
* Mon Feb 12 2024 trenn@suse.de
- Update to version 1.90.2+15:
  * Revert "ci: Update last ABI break"
  * Revert "build: Bump the library soname after recent changes"
  * Revert "all: Remove Lid handling"
  * Revert "lib: Remove deprecated up_client_get_devices()"
  * dbus: org.freedesktop.UPower: EnergyRate is a positive value
  * linux: Adjust test_bluetooth_le_device for dbusmock 0.30.1
  * linux: stop assuming power supply of unknown type as battery
  * linux: drop f-literals without format string
  * linux: prefer is not None over !=
  * build: make 'udevrulesdir' and 'udevhwdbdir' as Linux-only
- Introduce _service obs_scm and obsinfo files for automated
  update service via:
  osc service mr
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Own /usr/share/gtk-doc: glib no longer uses gtk-doc and as a
  consequence cannot be held responsible to deliver that basic
  directory structure.
* Sat Jul 15 2023 Dirk Müller <dmueller@suse.com>
- update to 1.90.2:
  * Note that this is the last release of UPower with lid
    handling. OS components that rely on the lid status
    should get it from logind instead.
  * Fix wireless devices not disappearing from Settings when
    disconnected
  * Require a newer libgudev to avoid bugs related to newline
    stripping when reading sysfs attributes
  * Add installed-tests files for use with gnome-desktop-testing
  * Fix integration test to work with system installed upower
    binary and under jhbuild
- add skip-tests-install.patch to skip installation of test-only
  assets
* Wed Jul  5 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.90.1:
  * Detect headsets with kernel batteries such as Logitech and
    Steelseries headsets, and make them automatically disappear if
    the headset is turned off (if the kernel driver supports the
    wireless_status attribute)
  * Hide duplicate Logitech Bluetooth devices (Bolt-compatible devices
    connected through Bluetooth would show as 2 batteries)
  * Hide duplicate Logitech wireless devices when they get connected
    through USB as well
  * Fix Bluetooth device names not synchronising, and use user-chosen
    names when available
  * Handle the "present" sysfs attribute changing
  * Fix iDevices not appearing
  * Fix reading capacity_level with newer libgudev
* Fri Sep  2 2022 Frederic Crozat <fcrozat@suse.com>
- update to 1.90.0:
  * Refactor internal battery handling into separate classes
  * Guess charging/discharging state based on energy rate (#196)
  * Fix polling after resume (#198)
  * Fix battery state guessing (#146)
  * Reload history when battery ID changes
  * Test fixes
- Drop upower-sle15.patch, systemd is recent enough for SLE15 SP3+.
* Sun Jul 17 2022 Dirk Müller <dmueller@suse.com>
- update to 0.99.20:
  * Ensure polling is resumed after suspend (#198)
  * Bugfixes to state guessing code (#146)
  * Stability improvements of automated tests
  * Move state guessing into DisplayDevice
  * Always use 90%% threshold to consider a battery full
  * Various test improvements
  * Fix mice showing up as keyboards (#189)
  * Allow unit test inspector to fail (#187)
  * Fix test cases when daemon shuts down too slowly (#188)
* Sun Jun  5 2022 Dirk Müller <dmueller@suse.com>
- update to 0.99.18:
  * Remove broken wakeup DBus API
  * Tag UPS hid devices using hwdb and update list from upstream
  * Only permit Refresh method when in debug mode
  * Refactor device polling
  * Refactor udev device discovery and sibling detection
  * Improved testing and CI
  * Handle SIGTERM to trigger a clean shutdown
  * Improve polling of batteries after line-power "online" status change
  * Multiple wacom tablet detection fixes
  * Fix updates after a BT hid power supply moves in sysfs
  * Fix enumeration of "Whats Up!" devices on startup
  * Accept USB power supplies without warning
  * Allow building without gtk-doc
* Fri Mar 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop downstream patch that hopefully should no longer be needed:
  + upower-hibernate-insteadof-hybridsleep.patch.
* Thu Mar 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.99.17:
  + Upstream release, no changes, versionbump only.
* Tue Mar  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.99.16+4:
  + meson.build: Output correct paths for sbindir and datadir.
  + daemon: Initialize FD to -1 to avoid incorrect close.
  + input: Fix FD handling and let input stream close it.
  + linux: Set FD to -1 rather than 0 when closing delay inhibitor.
* Fri Mar  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Pass --libexecdir=%%%%{_libexecdir}/upower to meson, keep our
  previous setup.
- Use ldconfig_scriptlets macro for post(un) handling.
- Stop removing .la files no longer present.
* Wed Mar  2 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.99.16:
  + Silence unnecessary udev event warnings
  + Increase test timeout
  + Explicitly link with plist
  + Fix UpClient reference leak
  + Fix DisplayDevice state on battery hotplug
  + Fix critical action to work after it was cancelled
- Changes from version 0.99.15:
  + Various build fixes
  + Update bluetooth device alias when it changes
- Changes from version 0.99.14:
  + Port build system to meson
  + New ChargeCycles D-Bus property
  + New async GLib APIs
  + lid related functions are now deprecated
  + Refresh API is now deprecated
  + Fix leak of inhibitor lock
  + Recognize USB power supplies
  + Fix time compression of data points
  + Fix disk write amplification when battery is low
- Add meson BuildRequires and macros following upstreams port.
* Thu Dec 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Use libplist 2 starting from SLE15SP4 on.
* Mon Aug 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.99.13:
  + Tweak default percentage levels to better match other operating
    systems.
  + Support large energy rates seen in some modern laptops.
  + Fix touchpads showing up as mice.
  + Fix composite battery state when multiple batteries are used
    and one isn't drawing any power.
  + Make the icon and warning properties respect the "low battery
    level" configuration option.
  + Stop the device being suspended during the 20-second "shutdown"
    grace period.
- Changes from version 0.99.12:
  + Add a raft of new device types.
  + Add support for iPhone XR, XS and newer models.
  + Work-around incorrect battery percentage reported by MacBooks.
  + Identify keyboard/pointing device combos as keyboards.
  + Fix small memory leak in Bluetooth backend.
  + Fix warning in Bluetooth backend.
  + Set update time in Bluetooth backend.
  + Remove support for obsolete CSR devices.
- Drop upower-build-Use-a-newer-libplist-if-available.patch: fixed
  upstream.
* Mon Jan 25 2021 Michal Suchanek <msuchanek@suse.com>
- Use libplist-2.0 on Tumblewewd.
  + upower-build-Use-a-newer-libplist-if-available.patch
* Thu Apr 30 2020 Thomas Renninger <trenn@suse.de>
- Remove _udevdir SLE12 specifics, this was an old compatibility
  hack, cmp with changelog entry from Mar 28 2017 - mgorse@suse.com
  jsc#SLE-12130
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Nov 21 2019 Frederic Crozat <fcrozat@suse.com>
- Add upower-sle15.patch: disable some systemd hardening,
  presenting upower to start with SLE15 SP2+ systemd.
- Switch back to setup/patch macros, autosetup doesn't allow
  skipping some patches.
* Tue Sep  3 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.99.11:
  + New Features:
  - Add code of conduct document.
  - build: Migrate from intltool to gettext.
  - rules: Split off HID++ udev rules.
  - Harden systemd service.
  - Let systemd create /var/lib/upower.
  - Move D-Bus policy file to /usr/share/dbus-1/system.d/.
  + Bug fixes:
  - Fix endless loop burning 100%% CPU on keyboard plugout with
    external backlight.
  - linux:
    . Start polling for unknown device batteries too.
    . Retry to get a battery type if it's unknown.
    . Don't treat device batteries like laptop batteries.
  - Replace use of G_TYPE_INSTANCE_GET_PRIVATE and
    g_type_class_add_private().
* Fri Mar 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to source service, so we do not have to deal with ever
  changing source url.
* Fri Mar 15 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.99.10:
  + Set 'pending-charge' for DisplayDevice if at least one battery
    is in the 'pending-charge' state.
  + Map pending-charge to fully-charged when charge is 100%%.
- Remove upower_daemon-consider-pending-charge.patch since the fix
  is now in the upstream codebase.
* Sun Jan 13 2019 bjorn.lie@gmail.com
- Add upower_daemon-consider-pending-charge.patch: daemon: Consider
  pending-charge when calculating the display state.
* Tue Nov  6 2018 bjorn.lie@gmail.com
- Update to version 0.99.9:
  + Fix lack of update after AC status changes, and broken keyboard
    backlight, following the daemon lockdown added in 0.99.8.
  + Multiple API documentation fixes.
  + Out-of-tree build fixes.
- Drop patches fixed upstream:
  + upower-remove-privatenetwork.patch.
  + upower-fix-keyboard-backlight.patch.
* Tue Oct 23 2018 bjorn.lie@gmail.com
- Add upower-fix-keyboard-backlight.patch: daemon: Fix upower's
  keyboard backlight support. Disabling kernel tunables blocked us
  from accessing /sys, meaning we couldn't change keyboard
  backlight levels.
* Wed Aug 15 2018 bjorn.lie@gmail.com
- Add upower-remove-privatenetwork.patch: Remove
  PrivateNetwork=true from upower.service. Upower needs to receive
  device uevents via AF_NETLINK socket otherwise it can't detect
  plug/unplug events.
  See https://gitlab.freedesktop.org/upower/upower/issues/68
* Sat Jul 28 2018 bjorn.lie@gmail.com
- Update to version 0.99.8:
  + New Features:
  - Lock down systemd service file.
  - Add support for "Unknown" capacity level, and clarify
    handling of devices with coarse battery levels.
  - Add a new version of up_client_get_devices() which unrefs
    contents.
  + Bugfixes:
  - Fix warnings when D-Bus related properties change.
  - Prevent crash after attaching an Apple TV, and support newer
    versions of iOS.
  - Lower severity of "unhandled action" messages.
  - Fix battery status on MacBooks after a plug or unplug event.
  - Fix double-close on exit.
- Drop patches fixed upstream:
  + upower-fix-ios-crash.patch.
  + upower-fix-crash-logind-doesnt-return-error.patch.
  + upower-fix-memory-leak.patch.
- Refresh upower-hibernate-insteadof-hybridsleep.patch with quilt.
- Use autosetup and make_build macros.
* Tue Jun  5 2018 bjorn.lie@gmail.com
- Add upower-fix-crash-logind-doesnt-return-error.patch: Fix crash
  if logind doesn't return an error.
- Add upower-fix-memory-leak.patch: Fix memory leak if logind
  returns an error.
* Thu May 24 2018 bjorn.lie@gmail.com
- Use %%%%config(noreplace) %%%%{_sysconfdir}/UPower/, if an admin have
  made changes to this config, we do not want to overwrite it on
  updates.
* Tue Mar 20 2018 novell@mirell.de
- Add upower-fix-ios-crash.patch to fix repeating crashes on some
  iOS devices like the Apple TV (fdo#105625).
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as license.
* Thu Nov 30 2017 mpluskal@suse.com
- Update to version 0.99.7:
  * New features:
    + Add support for Bluetooth LE device batteries
    + Allow to be replaced via --replace,-r
  * Bugfixes:
    + Fix critical action after resume from hibernate
    + Fix compilation with libimobiledevice git
- Changes for version 0.99.6:
  * New Features:
    + Add UP_DEVICE_KIND_GAMING_INPUT for gaming devices
    + Detect joysticks as gaming input devices
  * Bugfixes:
    + Correctly close inhibitor FD
    + Fix crash when '@' is present in the device name
    + Fix lid detection on FreeBSD
    + Grab the model name from device if unavailable from battery
- Refresh upower-hibernate-insteadof-hybridsleep.patch
* Mon Jul 24 2017 zaitor@opensuse.org
- Update to version 0.99.5:
  + New Features:
  - Add a more complete self test for HID++ devices.
  - Add BatteryLevel property for devices with a finite number of
    power levels.
  - Add support for pausing and resuming of the daemon poll.
  - Get a serial number for device batteries.
  - Refresh devices after waking up from sleep.
  + Bugfixes:
  - Add proper error and cancellable handling to UpClient
    constructor.
  - Do not spin in a loop when /proc/timer_stats cannot be
    written.
  - Exit early from up-tool when connecting to upower fails.
  - Expand the integration-tests to run in more environments.
  - Fix reading and writing the keyboard brightness level.
  - Fix -Wformat-y2k compilation errors.
  - Lower initial power usage when iDevice isn't accessible.
  - Simplify string checks in upower-glib.
- Drop upower-fix-get-critical-crash.patch: Fixed upstream.
* Tue Mar 28 2017 mgorse@suse.com
- Own udev directories on SLE, as SLE12 filesystem package
  doesn't own them. Require udev-devel in order to set _udevdir.
* Wed Oct 12 2016 dimstar@opensuse.org
- Add upower-hibernate-insteadof-hybridsleep.patch:
  + Set the system per default to hibernate, not hybridsleep. If
    the battery is going to be empty soon, there is no reason
    any longer to attempt to HybridSleep, which quite some hardware
    seems to get wrong. Simply hibernate, get the data on the disk
    and switch off (boo#985741).
* Fri Apr 15 2016 zaitor@opensuse.org
- Align BuildRequires with what configure looks for and version
  them:
  - Replace dbus-1-glib-devel, libgudev-1_0-devel,
    libimobiledevice-devel, libusb-devel and pkgconfig(udev)
  - with libtool, pkgconfig(dbus-glib-1), pkgconfig(gio-2.0),
    pkgconfig(gio-unix-2.0), pkgconfig(glib-2.0),
    pkgconfig(gobject-2.0), pkgconfig(gudev-1.0),
    pkgconfig(libimobiledevice-1.0), pkgconfig(libplist) and
    pkgconfig(libusb-1.0).
- Stop exporting V=1, we do debugging locally, so lets not clutter
  buildlogs.
* Thu Apr 14 2016 zaitor@opensuse.org
- Add upower-fix-get-critical-crash.patch: daemon: fix
  get_critical_action(), without this upower daemon will crash when
  trying to take action (boo#975653, fdo#94262).
* Wed Feb 17 2016 eshmarnev@suse.com
- Update to version 0.99.4:
  + Add support for Logitech G700s/G700 Gaming Mouse.
  + Port to GDBus.
  + Support g_autoptr() for all libupower-glib object types.
  + Add critical action support for *BSD.
  + Change the default low battery policy to percentage.
  + Fix deprecation warning in integration-test.
  + Fix memory leak in up_client_get_devices().
  + Fix possible double-free.
  + Update HID rules and fix build regression.
* Fri Jun 19 2015 mpluskal@suse.com
- Update to version 0.99.3
  * Bail out when iDevice state is malformed (Bastien Nocera)
  * Defer getting iDevice info until ready (Bastien Nocera)
  * Fix crash on uninitialized variant (Vlad Orlov)
  * Fix libimobiledevice msg in configure (Bastien Nocera)
  * More memory handling fixes in iDevice (Bastien Nocera)
  * Properly detect bluetooth mice and keyboards that are HID
    devices (Marc Deslauriers)
  * Support Logitech Unifying in Linux 3.19 (Peter Wu)
  * Work-around broken battery on the Onda v975w (Bastien Nocera)
- Add missing rcsymlink
- Remove old provides/obsoletes
- Do not recommend obsolete pm-utils
* Fri Dec 19 2014 hrvoje.senjan@gmail.com
- Update to version 0.99.2:
  + Bugfixes:
  - Avoid unaligned memory access in hidpp-device
  - Bump GLib min req to 2.34
  - Correct check to prevent the display of invalid ASCII codes
  - Fencepost array access error
  - Fix cleanup in up_device_idevice_coldplug/finalize
  - Fix crash if there is no session D-BUS
  - Fix error handling for Python 3.4
  - Fix various memory and reference leaks
  - Release resources at shutdown
  - Respect the CriticalPowerAction config option
  - Set update-time on the aggregate device
  - Split out updating on_battery and warning_level
  - Update aggregate device on battery removal
  - Update display device when battery is removed
  - Use g_get_real_time() when possible
- Restore Source URL
- Remove autoconf, automake and libtool BuildRequires, not needed
* Thu Dec  4 2014 hrvoje.senjan@gmail.com
- Update to latest git head, to resolve various memleaks,
  (fdo#82659, boo#904520)
- Added autoconf, automake and libtool BuildRequires, needed with
  git packaging
- Comment out the full Source URL, the updated tarball is not
  available at fdo URL
* Thu Aug 21 2014 mgorse@suse.com
- Update to version 0.99.1:
  + New Features:
  - Remove IsDocked property
  - Remove unused polkit dependency
  + Bugfixes:
  - Create the history directory at runtime
  - Do not log a critical warning when using
    _set_object_path_sync()
  - Fix API doc for up_client_get_on_battery()
  - Fix possible UpHistoryItem leak on failure
  - Fix segfault on getting property when daemon is not running
  - Fix shutdown on boot on some machines
  - Fix small memleak on startup with Logitech devices
  - Free the obtained device list array after use
  - Update lid status when updating AC status
- Remove upower-fix-leaks.patch: fixed upstream.
- Adjust package name, since LT_CURRENT is now 3
* Fri Aug  1 2014 mgorse@suse.com
- Add upower-fix-leaks.patch: fix a couple of memory leaks.
* Sun Nov 24 2013 crrodriguez@opensuse.org
- define _udevrulesdir only if not already defined
- run %%udev_rules_update, if defined.
* Sun Nov  3 2013 hrvoje.senjan@gmail.com
- Update to version 0.99.0:
  + Notes:
  - This version contains major API changes. Use the 0.9.*
    versions if you want to keep using the old API.
  + New Features:
  - Add WarningLevel and IconName properties to all devices
  - Add DisplayDevice composite battery
  - Enforce critical battery policy on the daemon side
  + Bugfixes:
  - Reduce client-side and daemon-side wake-ups
  - Emit PropertiesChanged signals
  - Register objects on the bus once they've been setup
  - Clamp percentage for overfull batteries
  + Feature Removals:
  - Remove battery recall support
  - Remove QoS support
  - Remove OnLowBattery property (use WarningLevel instead)
  - Remove DeviceChanged and Changed signals (PropertiesChanged
    signals are sent instead)
* Sun Oct 20 2013 hrvoje.senjan@gmail.com
- Update to version 0.9.23:
  + Bugfixes:
  - Add missing dbus-glib-1 to private requires
  - Disable Watts-Up devices by default
  - Really don't overwrite retval with prop values
  - Update and correct Toshiba recall list
  - daemon: Avoid trying to close fd that wasn't opened
  - daemon: Fix options parsing
  - daemon: Include config.h in up-backend.h
  - lib: Add missing "element-type" introspection metadata
  - lib: Fix a small memory leak
  - lib: Fix crasher calling _about_to_sleep_sync()
  - linux: Don't guess discharging state for devices
  - linux: Don't print a warning if the status attr is missing
  - linux: Opt-out of checking Watts Up devices earlier
  - openbsd: Use g_thread_try_new
  - openbsd: recognize when battery is absent
* Tue Oct  8 2013 hrvoje.senjan@gmail.com
- Update to version 0.9.22:
  + New Features:
  - Add temperature property for batteries
  + Bugfixes:
  - Fix error handling in up_client_get_properties_sync()
  - Make GetHistory() array order consistent
  - Fix crash with bluetooth input devices
  - Lots of fixes/rework for Logitech wireless input devices
  - Allow valid UTF-8 encoded properties
  - Detect the battery of bluetooth input devices
  - Only one warning if no valid voltage found
  - openbsd: Do not call g_thread_init()
* Fri Jul 26 2013 hrvoje.senjan@gmail.com
- Update to version 0.9.21:
  + New Features:
  - Add support for Logitech Wireless (NonUnifying) devices
  - Use PIE to better secure installed tools and also use
    full RELRO in the daemon
  + Bugfixes:
  - Allow clients to call org.freedesktop.DBus.Peer
  - Detect udev rules dir
  - Drop --enable-systemd and linking to libsystemd-daemon
  - Find hidraw devices correctly with systemd udev >= v196
  - Fix test for logind availability
  - Update the upower man page with all the current options
- Dropped systemd define, systemd usage is now detected at runtime
- Pass %%{_udevrulesdir} to %%configure, instead of %%makeinstall
- Unconditionally install notify-upower.sh
- Dropped pkgconfig(libsystemd-daemon) BuildRequires, not needed
  with this release
* Sat Apr  6 2013 hrvoje.senjan@gmail.com
- Add --enable-deprecated flag (bnc#813883) which restores
  upowers sleep/resume funcionality
* Mon Mar 18 2013 hrvoje.senjan@gmail.com
- Update to version 0.9.20:
  + New Features:
  - Add a --enable-deprecated configure argument to remove pm-utils
    support
  - Deprecate running the powersave scripts
  - Factor out the Logitech Unifying support to support other
    devices
  - Require applications to define UPOWER_ENABLE_DEPRECATED to use
    deprecated functionality
  + Bugfixes:
  - Bump maximum accepted "time to empty" to 10 days
  - Don't use the deprecated INCLUDES in Makefile.am
  - Fix batteries which report current energy but full charge
  - Fix K750 features name, use 1 second interval
  - Fix memory leak in up_polkit_get_subject
  - Fix two memory leaks
  - integration-test: Always run on a fake system bus
  - integration-test: Move to using umockdev
  - Never use -WError when building
  - Raise the hard PolicyKit dep to 0.97
* Fri Jan  4 2013 hrvoje.senjan@gmail.com
- Update to version 0.9.19:
  + New Features:
  - Add a Documentation tag to the service file
  - Add luminosity property
  - Add support for Logitech Unifying devices
  + Bugfixes:
  - Always return 0 from notify-upower.sh
  - Do not continue to poll if /proc/timer_stats is not readable
  - Fix "can-hibernate" formatting in upower --dump
  - Fix device matching for recent kernels
  - Fix srcdir != builddir
  - Send resume signal when built with systemd and using pm-utils
    suspend
  - Drop upower-fix-resume-no-systemd.patch, merged upstream
* Wed Nov 21 2012 nmo.marques@gmail.com
- Add 'pm-utils' to Recommends; gnome-power-manager and
  mate-power-manager (at least) use upower for some features, some
  features like suspend/hibernate only show if 'pm-utils' is also
  installed. See bnc#790787. I believe this is an improvement.
- Add macro systemdutildir and fix broken build and drop FIXME
  comment
* Sun Nov  4 2012 crrodriguez@opensuse.org
- Enable systemd support, now we have version 195
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new udev rules location
* Mon Sep 17 2012 vuntz@opensuse.org
- Pass --disable-systemd to configure if we don't build systemd
  support. Fix bnc#780709.
* Tue Sep 11 2012 vuntz@opensuse.org
- Update to version 0.9.18:
  + New Features:
  - Use systemd if possible for suspend and hibernate
  + Bugfixes:
  - openbsd: Properly initialize update-time when creating
    devices
- Changes from version 0.9.17:
  + New Features:
  - Fail on CRITICALs in the integration-test
  + Bugfixes:
  - Drop 'type' parameter from CancelRequest() signature
  - Fix the LatencyChanged signal
  - Fix use-after-free of qos item
  - Fix wrong PowerSupply property for devices without a scope
    sysfs attribute
  - linux:
    + Don't allow non-power-supply devices to set the OnBattery
    property
    + Remove obsolete check for magicmouse_ and duplicated wacom_
    checks
    + Treat the battery state 'not charging' as PENDING_CHARGE
  - Selectively disable warnings for deprecated GValueArray
- Drop xz BuildRequires as it now comes for free in the build
  system.
- Get ready for full-switch to systemd for suspend and hibernate:
  + Add a with_systemd macro, currently set to 0 as we would need
    systemd >= 183, which we don't have right now.
  + Add pkgconfig(libsystemd-daemon) BuildRequires if we build
    systemd support.
  + Pass --enable-systemd to configure if we build systemd support.
  + Do not install /lib/systemd/system-sleep/notify-upower.sh if we
    don't build with systemd support.
- Add upower-fix-resume-no-systemd.patch: fix resuming when not
  booted with systemd.
* Fri May 11 2012 vuntz@opensuse.org
- Update to version 0.9.16:
  + New Features:
  - Add boolean RunPowersaveCommand to UPower.conf
  - Install a systemd service file if systemd is used
  + Bugfixes:
  - Clamp the UPS percentage from 0 to 100 to fix syslog spam
  - Correct the cap on the energy rate
  - Do not print error message for missing /etc/crypttab
  - Fix crash in up_device_csr_finalize
  - Never detect HID devices with batteries as power supplies
  - Re-coldplug dock status when resuming from sleep
  - Return all history records for a timespan of zero
  - libupower-glib: fix small memory leak
  - libupower-glib: srcdir != builddir fix
  - OpenBSD fixes
- Correctly package systemd service file:
  + Add pkgconfig(systemd) BuildRequires.
  + Use %%{?systemd_requires} and add %%service_add_{pre,post} and
    %%service_del_{preun,postun} in scriptlets.
* Wed Feb 15 2012 vuntz@opensuse.org
- Move dbus xml interface files from devel subpackage to main
  subpackage: those files might be needed at runtime.
* Mon Jan  9 2012 vuntz@opensuse.org
- Remove glib2-devel Requires from libupower-glib-devel: it will
  automatically be added the pkgconfig() way.
* Mon Jan  9 2012 glin@suse.com
- Split typelib file into typelib-1_0-UpowerGlib-1_0 subpackage.
- Add typelib-1_0-UpowerGlib-1_0 Requires to libupower-glib-devel.
* Fri Dec 16 2011 crrodriguez@opensuse.org
- Update to version 0.9.15
* Tue Oct  4 2011 vuntz@opensuse.org
- Update to version 0.9.14:
  + New Features:
  - Filter the debugging details unless --verbose is specified
  + Bugfixes:
  - Fix linux up_backend_supports_sleep_state() return code
  - Fix the kFreeBSD detection
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 0.9.13:
  + New Features:
  - Modernize build system.
  + Bugfixes:
  - Avoid warnings about missing annotations
  - Don't rely on files' presence to define the default backend
  - Fully port the test suite to use GObject Introspection
  - Hardcode wacom battery devices as not power-supply devices
  - Use autoreconf instead of custom script
  - Use g_unix_signal_add_full() which has been renamed in GLib
* Sat Jul 23 2011 andrea.turrini@gmail.com
- Fixed typo in description of upower.spec
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 0.9.12:
  + Bugfixes:
  - Fix how we estimate the device rate for batteries that do not
    provide this data
  - Add AC_PROG_LIBTOOL as advised by autotools
  - Add openbsd missing includes for close and strcmp
  - Silence some openbsd warnings about unused vars and bad
    return values
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Tue Jun 14 2011 aj@suse.de
- Update to 0.9.11:
  + New feature:
  - Add new NotifySleep() and NotifyResume() signals that include
    the sleep type
  + Bugfixes:
  - Ensure up-apm-native.h gets shipped in the tarball for
    OpenBSD
  - Check energy vs. charge in the Linux integration tests
  - Only include glib-unix.h if the GLib version is >= 2.29.4
  - Respect $PYTHON for running the test suite
  - Run subset of tests when system D-BUS is not available
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 0.9.10:
  + New Features:
  - Add a config option 'IgnoreLid' for users with broken lid
    switches
  - Add integration test suite for Linux
  - Add option to run daemon on the session bus for testing
  - Add OpenBSD backend which uses the APM_IOC_GETPOWER ioctl()
  - Support virtual UPS devices for testing
  + Bugfixes:
  - Consider a discharging UPS as "on battery"
  - Do not overwrite aclocal flags in autogen, fdo#35261
  - Fix "unknown" battery status guessing to not be recursive
  - Respect $UPOWER_CONF_FILE_NAME in up_config_init
  - Support batteries that report both energy and charge
  - upower needs -pthread
  - Use the new threadsafe signal handling support in GLib
  - Wuninitialized needs -O
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 0.9.9:
  + New Features:
  - Add a config option to disable the Watts Up Pro device
  - Add a LidForceSleep property to ensure that we don't melt any
    laptops
  - Add an option for polling dock devices in UPower.conf,
    defaulting to false.
  + Bugfixes:
  - Depend on stable GUdev API
  - Drop devkit and devkit-power-daemon symlinks
  - Fix bitmap check in the input code
  - Honour ACLOCAL_FLAGS in Makefile.am
- Drop DeviceKit-power subpackage and obsolete old version of it.
* Sun Jan  9 2011 vuntz@opensuse.org
- Update to version 0.9.8:
  + New Features:
  - Add an IsDocked binary property to the main interface
  - Use the number of active DRM devices to determine the system
    docked status
  + Bugfixes:
  - Add method to set history dir
  - Check for and link against libplist
  - Drop check for polkit-backend again
  - Fix compilation error against Linux 2.6.36
  - Fix links to git repository in HACKING
  - Fix self check to work as non-root
  - Re-add AM_MAINTAINER_MODE (but enable it by default)
  - Reduce race condition in history purging self check
  - Support the power_now sysfs attribute to get time remaining
    on new kernels
  - Update the list of HID UPS devices
* Wed Nov 10 2010 vuntz@opensuse.org
- Update to version 0.9.7:
  + New Features:
  - Add support for controlling leds keyboard backlights
  - Port from EggDebug to the GLib built-in logging framework
  + Bugfixes:
  - Fix building with gobject-introspection 0.9.10
  - Fix up all the warnings when building with new versions of
    gobject-introspection
  - Keyboard backlight of zero is not an error
  - libupower-glib: Reject invalid object paths to avoid
    asserting libdbus
  - Remove the UP_DEVICE_SUPPLY_CHARGED_THRESHOLD heuristic
  + Updated translations.
- Add gobject-introspection-devel BuildRequires to build
  introspection data.
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 0.9.6:
  + Remove devkit-power-gobject
  + Bugfixes:
  - Allow explicitly disabling libimobiledevice support
  - Free GErrors after returning them
  - Add missing D-Bus return in up_qos_cancel_request()
  - Fix double D-BUS return in up_daemon_*_allowed
  - Fix up_polkit_get_subject() D-BUS error return
  - Ensure the new device types get valid descriptions in upower
  - -dump
  - Fix compile with the latest PolicyKit release
  - Only save by default 7 days data to stop the log files
    becoming huge. Fixes rh#634228
  - Do not continue to poll the serial port if there is no Watts
    Up Pro adaptor
  - Fix the build with new versions of gobject-introspection
- Drop upower-fix-crash.patch: fixed upstream.
- Remove libdevkit-power-gobject1, libdevkit-power-gobject-devel
  subpackages.
* Tue Sep 28 2010 aj@suse.de
- Recommend instead of require lang-package.
* Wed Sep 22 2010 vuntz@opensuse.org
- Add upower-fix-crash.patch to fix a crash with recent versions of
  polkit. Fix bnc#640940.
* Fri Jul 16 2010 vuntz@opensuse.org
- Update to version 0.9.5:
  + New Features:
  - Add battery query support for iDevices
  - Assign names to our idle sources when using new versions of
    glib2
  - Dynamic testing for enough hibernate swap
  - Port UPower to libusb1 to avoid unfixable crashes
  - Port to GTest
  - Get the powersave command from the backend rather than
    hardcoding Linux specifics
  + Bugfixes:
  - Update the list of supported TrippLite HID Power Devices
  - Fix a potential daemon crash. Fixes fdo#27902
  - Increase UP_DAEMON_SWAP_WATERLINE
  - Fix up a potential crasher in the CSR device code
  - When calculating used swap space, only use anonymous pages
  - Use pm-is-supported to test if various sleep modes are
    supported
- Add libimobiledevice-devel BuildRequires for the iDevices
  support.
* Mon Jun 21 2010 vuntz@opensuse.org
- Update to version 0.9.4:
  + New Features:
  - Detect when the kernel changes the reported charge units.
    Fixes rh#587112
  + Bugfixes:
  - Only emit ::Sleeping() after we've checked AboutToSleep
  - Ensure we send ::Sleeping() if clients do not call
    AboutToSleep
  - Ensure we sent ::notify signals when UpDaemon properties
    change
- Changes from version 0.9.3:
  + New Features:
  - Add a config file with SleepTimeout and
    AllowHibernateEncryptedSwap entries
  + Bugfixes:
  - Fix c&p typo in documentation
  - The gettext package should match the tarball name
  - Provide UpDaemon with C setters rather than relying on
    GObject properties
  - Sanity check the device is not already in the list before
    adding
  - Fix recognition of lithium iron phosphate (LiFePO4) batteries
- Changes from version 0.9.2:
  + New Features:
  - Add a missing accessor: up_client_get_lid_is_present()
  - Change the tarball name to be all lower case to match udisks
    and udev
  - Convert the daemon to using objects from libupower-glib, not
    devkit-power-gobject
  - Do not allow client programs to enumerate the device list
    more than once
  - Get the encrypted swap status from the backend, rather than
    hardcoding Linux specifics
  - Get the kernel sleep capabilities from the backend, rather
    than hardcoding Linux specifics
  - Get the suspend and hibernate commands from the backend,
    rather than hardcoding Linux specifics
  - Get the swap size from the backend, rather than hardcoding
    Linux specifics
  - Show in ./configure summary if unit tests have been enabled
    or not
  + Bugfixes:
  - Do not warn what we are correcting energy-full when there is
    no data to copy
  - Ensure we enumerate devices before we start monitoring them
  - Fixes to the autogen.sh script
  - Make dummy backend usable for architectures without a native
    backend
  - Remove libdevkit-power-gobject dependency from backends
  - Simplify udev subdirectory handling
- Update the spec file for the case change in the tarball name.
* Tue Mar 23 2010 vuntz@opensuse.org
- First package of upower, the new name of DeviceKit-power. The
  packaging is loosely based on the DeviceKit-power packaging.
- Note that we provide compatibility package for DeviceKit-power
  for now.
